@@ -17,7 +17,12 @@ import aws_cdk.aws_sns._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ses-actions", "1.45.0", __name__[0:-6], "aws-ses-actions@1.45.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-ses-actions",
+    "1.52.0",
+    __name__[0:-6],
+    "aws-ses-actions@1.52.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
